@@ -277,7 +277,7 @@ init_content (GtkTreeView *treeview)
 		keycode = gconf_client_get_int (conf_client,
 				keys[i].key_config, NULL);
 		init_content_helper (store, keys[i].key_config,
-				keys[i].description, keycode);
+				_(keys[i].description), keycode);
 	}
 }
 
